/*
 * Copyright 2014 (c) Anna Schumaker.
 */
#include <core/audio.h>
#include <core/playlist.h>
#include <gui/tabs.h>


static Gtk::ToggleButton *o_ban;
static Gtk::ToggleButton *o_fav;
static Gtk::TreeView     *p_treeview;
static Glib::RefPtr<Gtk::ListStore> p_list;

static Glib::ustring current_playlist();


static class PlaylistColumns : public Gtk::TreeModelColumnRecord {
public:
	Gtk::TreeModelColumn<Glib::ustring> p_name;
	PlaylistColumns() { add(p_name); }
} p_cols;



static class PlaylistTab : public Tab {
public:
	PlaylistTab() : Tab(playlist :: get_queue())
	{
		tab_search   = gui :: get_widget<Gtk::SearchEntry>("o_playlist_entry");
		tab_treeview = gui :: get_widget<Gtk::TreeView>("o_playlist_pq_treeview");
		tab_widget   = gui :: get_widget<Gtk::Widget>("o_playlist_page");
		tab_finish_init();
	}

	~PlaylistTab()
	{
		tab_unmap();
	}

	bool on_key_press_event(const std::string &key)
	{
		std::string cur;
		std::vector<unsigned int> ids;

		if (key != "Delete")
			return Tab :: on_key_press_event(key);

		cur = current_playlist();
		if (cur == "")
			return true;

		tab_selected_ids(ids);
		for (unsigned int i = 0; i < ids.size(); i++)
			playlist :: del(tags :: get_track(ids[i]), cur);
		return true;
	}
} *p_tab;



static Glib::ustring current_playlist()
{
	Gtk::TreePath path;
	Gtk::TreeModel::Row row;
	Gtk::TreeViewColumn *col;

	p_treeview->get_cursor(path, col);
	row = *(p_list->get_iter(path));
	return row[p_cols.p_name];
}

static void on_cursor_changed()
{
	playlist :: select(current_playlist());
}

static bool on_clicked(GdkEventButton *button)
{
	return button->button == 3;
}

static void on_ban()
{
	Track *track = audio :: current_track();
	if (o_ban->get_active()) {
		if (!playlist :: has(track, "Banned")) {
			playlist :: add(track, "Banned");
			audio :: next();
		}
	} else
		playlist :: del(track, "Banned");
}

static void on_favorite()
{
	Track *track = audio :: current_track();
	if (o_fav->get_active())
		playlist :: add(track, "Favorites");
	else
		playlist :: del(track, "Favorites");
}



void plist :: track_loaded(Track *track)
{
	o_ban->set_active(playlist :: has(track, "Banned"));
	o_fav->set_active(playlist :: has(track, "Favorites"));
}

void plist :: init()
{
	p_tab = new PlaylistTab;
	p_list = gui :: get_object<Gtk::ListStore>("plist_list");
	p_treeview = gui :: get_widget<Gtk::TreeView>("plist_treeview");

	p_treeview->signal_cursor_changed().connect(sigc::ptr_fun(on_cursor_changed));
	p_treeview->signal_button_press_event().connect(sigc::ptr_fun(on_clicked));

	o_ban = gui :: get_widget<Gtk::ToggleButton>("o_ban");
	o_fav = gui :: get_widget<Gtk::ToggleButton>("o_favorite");

	o_ban->signal_toggled().connect(sigc::ptr_fun(on_ban));
	o_fav->signal_toggled().connect(sigc::ptr_fun(on_favorite));
}
